@@ -18,7 +18,7 @@ def messagePreprocess(message: str):
     contained_images = {}
     images = re.findall(r'\[CQ:image.*?]', message)
     for i in images:
-        contained_images.update({i: [re.findall(r'\[.*url=(.*?),.*]', i)[0], re.findall(r'\[.*file=(.*?),.*]', i)[0]]})
+        contained_images.update({i: [re.findall(r'url=(.*?)[,\]]', i)[0][0], re.findall(r'file=(.*?)[,\]]', i)[0][0]]})
     for i in contained_images:
         message = message.replace(i, f'[{contained_images[i][1]}]')
     return message, raw_message
